# Bacteria Documentation

This project was developed during my pre doctoral rotation at the [Global regulation for bacterial adaptation](https://sites.google.com/site/biancasclavi/) supervised by Bianca Sclavi. This repository holds all the code and documentation developed during this time. A pipeline was developed to analyze image data using SuperSegger and Omnipose ([Pipeline Documentation](https://github.com/tuliofalmeida/bacteria/tree/main/pipeline)), a library to process this data, called Bacteria ([Bacteria Documentation Site](https://bacteria.readthedocs.io/en/latest/index.html)) and also the 3D modeling designs to fix the plate with PDMS to the centrifuge and distribute the bacteria in all channels of the microfluidic device ([3D models folder](https://github.com/tuliofalmeida/bacteria/tree/main/models)).